# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class MonitorServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def monitor_service_create_custom_monitor(self, body, name, **kwargs):  # noqa: E501
        """CreateCustomMonitor  # noqa: E501

        Create a new custom monitor  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_create_custom_monitor(body, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustommonitorsNameBody body: (required)
        :param str name: The name of the monitor. (required)
        :return: RimeCreateCustomMonitorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_service_create_custom_monitor_with_http_info(body, name, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_service_create_custom_monitor_with_http_info(body, name, **kwargs)  # noqa: E501
            return data

    def monitor_service_create_custom_monitor_with_http_info(self, body, name, **kwargs):  # noqa: E501
        """CreateCustomMonitor  # noqa: E501

        Create a new custom monitor  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_create_custom_monitor_with_http_info(body, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CustommonitorsNameBody body: (required)
        :param str name: The name of the monitor. (required)
        :return: RimeCreateCustomMonitorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_service_create_custom_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `monitor_service_create_custom_monitor`")  # noqa: E501
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `monitor_service_create_custom_monitor`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/custom-monitors/{name}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateCustomMonitorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monitor_service_delete_custom_monitor(self, monitor_id_uuid, **kwargs):  # noqa: E501
        """DeleteCustomMonitor  # noqa: E501

        Delete a custom monitor  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_delete_custom_monitor(monitor_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitor_id_uuid: Unique object ID. (required)
        :return: RimeDeleteCustomMonitorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_service_delete_custom_monitor_with_http_info(monitor_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_service_delete_custom_monitor_with_http_info(monitor_id_uuid, **kwargs)  # noqa: E501
            return data

    def monitor_service_delete_custom_monitor_with_http_info(self, monitor_id_uuid, **kwargs):  # noqa: E501
        """DeleteCustomMonitor  # noqa: E501

        Delete a custom monitor  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_delete_custom_monitor_with_http_info(monitor_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitor_id_uuid: Unique object ID. (required)
        :return: RimeDeleteCustomMonitorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['monitor_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_service_delete_custom_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'monitor_id_uuid' is set
        if ('monitor_id_uuid' not in params or
                params['monitor_id_uuid'] is None):
            raise ValueError("Missing the required parameter `monitor_id_uuid` when calling `monitor_service_delete_custom_monitor`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id_uuid' in params:
            path_params['monitorId.uuid'] = params['monitor_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/custom-monitors/{monitorId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteCustomMonitorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monitor_service_get_monitor_result(self, monitor_id_uuid, **kwargs):  # noqa: E501
        """GetMonitorResult  # noqa: E501

        Graph a monitor within a time range  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_get_monitor_result(monitor_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitor_id_uuid: Unique object ID. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: RimeGetMonitorResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_service_get_monitor_result_with_http_info(monitor_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_service_get_monitor_result_with_http_info(monitor_id_uuid, **kwargs)  # noqa: E501
            return data

    def monitor_service_get_monitor_result_with_http_info(self, monitor_id_uuid, **kwargs):  # noqa: E501
        """GetMonitorResult  # noqa: E501

        Graph a monitor within a time range  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_get_monitor_result_with_http_info(monitor_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitor_id_uuid: Unique object ID. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: RimeGetMonitorResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['monitor_id_uuid', 'time_interval_start_time', 'time_interval_end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_service_get_monitor_result" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'monitor_id_uuid' is set
        if ('monitor_id_uuid' not in params or
                params['monitor_id_uuid'] is None):
            raise ValueError("Missing the required parameter `monitor_id_uuid` when calling `monitor_service_get_monitor_result`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id_uuid' in params:
            path_params['monitorId.uuid'] = params['monitor_id_uuid']  # noqa: E501

        query_params = []
        if 'time_interval_start_time' in params:
            query_params.append(('timeInterval.startTime', params['time_interval_start_time']))  # noqa: E501
        if 'time_interval_end_time' in params:
            query_params.append(('timeInterval.endTime', params['time_interval_end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/monitors/result/{monitorId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetMonitorResultResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monitor_service_get_time_series(self, project_id_uuid, time_series_name, **kwargs):  # noqa: E501
        """GetTimeSeries returns a time series of a given project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_get_time_series(project_id_uuid, time_series_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str time_series_name: Uniquely specifies a time series data. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: RimeGetTimeSeriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_service_get_time_series_with_http_info(project_id_uuid, time_series_name, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_service_get_time_series_with_http_info(project_id_uuid, time_series_name, **kwargs)  # noqa: E501
            return data

    def monitor_service_get_time_series_with_http_info(self, project_id_uuid, time_series_name, **kwargs):  # noqa: E501
        """GetTimeSeries returns a time series of a given project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_get_time_series_with_http_info(project_id_uuid, time_series_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param str time_series_name: Uniquely specifies a time series data. (required)
        :param datetime time_interval_start_time:
        :param datetime time_interval_end_time:
        :return: RimeGetTimeSeriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'time_series_name', 'time_interval_start_time', 'time_interval_end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_service_get_time_series" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `monitor_service_get_time_series`")  # noqa: E501
        # verify the required parameter 'time_series_name' is set
        if ('time_series_name' not in params or
                params['time_series_name'] is None):
            raise ValueError("Missing the required parameter `time_series_name` when calling `monitor_service_get_time_series`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501
        if 'time_series_name' in params:
            path_params['timeSeriesName'] = params['time_series_name']  # noqa: E501

        query_params = []
        if 'time_interval_start_time' in params:
            query_params.append(('timeInterval.startTime', params['time_interval_start_time']))  # noqa: E501
        if 'time_interval_end_time' in params:
            query_params.append(('timeInterval.endTime', params['time_interval_end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/monitors/time-series/{projectId.uuid}/{timeSeriesName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetTimeSeriesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monitor_service_list_metric_identifiers(self, firewall_id_uuid, **kwargs):  # noqa: E501
        """ListMetricIdentifiers  # noqa: E501

        List all possible Custom Monitor Metric Identifiers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_list_metric_identifiers(firewall_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_id_uuid: Unique object ID. (required)
        :return: RimeListMetricIdentifiersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_service_list_metric_identifiers_with_http_info(firewall_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_service_list_metric_identifiers_with_http_info(firewall_id_uuid, **kwargs)  # noqa: E501
            return data

    def monitor_service_list_metric_identifiers_with_http_info(self, firewall_id_uuid, **kwargs):  # noqa: E501
        """ListMetricIdentifiers  # noqa: E501

        List all possible Custom Monitor Metric Identifiers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_list_metric_identifiers_with_http_info(firewall_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_id_uuid: Unique object ID. (required)
        :return: RimeListMetricIdentifiersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['firewall_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_service_list_metric_identifiers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'firewall_id_uuid' is set
        if ('firewall_id_uuid' not in params or
                params['firewall_id_uuid'] is None):
            raise ValueError("Missing the required parameter `firewall_id_uuid` when calling `monitor_service_list_metric_identifiers`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'firewall_id_uuid' in params:
            path_params['firewallId.uuid'] = params['firewall_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/custom-monitors/metrics/{firewallId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListMetricIdentifiersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monitor_service_list_monitors(self, firewall_id_uuid, **kwargs):  # noqa: E501
        """ListMonitors  # noqa: E501

        lists monitors by firewall ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_list_monitors(firewall_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_id_uuid: Unique object ID. (required)
        :param list[str] first_page_req_included_monitor_types: Specifies a list of monitor types. Filters results to match the specified monitor types.
        :param list[str] first_page_req_included_risk_category_types: Specifies a list of risk category types. Filters results to match the specified risk category types.
        :param bool first_page_req_pinned_monitors_only: When the value of this Boolean is True, this endpoint returns a list of pinned Monitors. Otherwise, this endpoint does not filter Monitors by pinned status.
        :param str page_token: Specifies a page of the list returned by a ListMonitors query. The ListMonitors query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Monitor objects to return in a single page.
        :return: RimeListMonitorsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_service_list_monitors_with_http_info(firewall_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_service_list_monitors_with_http_info(firewall_id_uuid, **kwargs)  # noqa: E501
            return data

    def monitor_service_list_monitors_with_http_info(self, firewall_id_uuid, **kwargs):  # noqa: E501
        """ListMonitors  # noqa: E501

        lists monitors by firewall ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_list_monitors_with_http_info(firewall_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str firewall_id_uuid: Unique object ID. (required)
        :param list[str] first_page_req_included_monitor_types: Specifies a list of monitor types. Filters results to match the specified monitor types.
        :param list[str] first_page_req_included_risk_category_types: Specifies a list of risk category types. Filters results to match the specified risk category types.
        :param bool first_page_req_pinned_monitors_only: When the value of this Boolean is True, this endpoint returns a list of pinned Monitors. Otherwise, this endpoint does not filter Monitors by pinned status.
        :param str page_token: Specifies a page of the list returned by a ListMonitors query. The ListMonitors query returns a pageToken when there is more than one page of results. Specify either this field or the firstPageReq field.
        :param str page_size: The maximum number of Monitor objects to return in a single page.
        :return: RimeListMonitorsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['firewall_id_uuid', 'first_page_req_included_monitor_types', 'first_page_req_included_risk_category_types', 'first_page_req_pinned_monitors_only', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_service_list_monitors" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'firewall_id_uuid' is set
        if ('firewall_id_uuid' not in params or
                params['firewall_id_uuid'] is None):
            raise ValueError("Missing the required parameter `firewall_id_uuid` when calling `monitor_service_list_monitors`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'firewall_id_uuid' in params:
            path_params['firewallId.uuid'] = params['firewall_id_uuid']  # noqa: E501

        query_params = []
        if 'first_page_req_included_monitor_types' in params:
            query_params.append(('firstPageReq.includedMonitorTypes', params['first_page_req_included_monitor_types']))  # noqa: E501
            collection_formats['firstPageReq.includedMonitorTypes'] = 'multi'  # noqa: E501
        if 'first_page_req_included_risk_category_types' in params:
            query_params.append(('firstPageReq.includedRiskCategoryTypes', params['first_page_req_included_risk_category_types']))  # noqa: E501
            collection_formats['firstPageReq.includedRiskCategoryTypes'] = 'multi'  # noqa: E501
        if 'first_page_req_pinned_monitors_only' in params:
            query_params.append(('firstPageReq.pinnedMonitorsOnly', params['first_page_req_pinned_monitors_only']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/monitors/{firewallId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListMonitorsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def monitor_service_update_monitor(self, body, monitor_id_uuid, **kwargs):  # noqa: E501
        """UpdateMonitor  # noqa: E501

        Updates a monitor.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_update_monitor(body, monitor_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MonitorsMonitorIdUuidBody body: (required)
        :param str monitor_id_uuid: Unique object ID. (required)
        :return: RimeUpdateMonitorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.monitor_service_update_monitor_with_http_info(body, monitor_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.monitor_service_update_monitor_with_http_info(body, monitor_id_uuid, **kwargs)  # noqa: E501
            return data

    def monitor_service_update_monitor_with_http_info(self, body, monitor_id_uuid, **kwargs):  # noqa: E501
        """UpdateMonitor  # noqa: E501

        Updates a monitor.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.monitor_service_update_monitor_with_http_info(body, monitor_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MonitorsMonitorIdUuidBody body: (required)
        :param str monitor_id_uuid: Unique object ID. (required)
        :return: RimeUpdateMonitorResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'monitor_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method monitor_service_update_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `monitor_service_update_monitor`")  # noqa: E501
        # verify the required parameter 'monitor_id_uuid' is set
        if ('monitor_id_uuid' not in params or
                params['monitor_id_uuid'] is None):
            raise ValueError("Missing the required parameter `monitor_id_uuid` when calling `monitor_service_update_monitor`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id_uuid' in params:
            path_params['monitor.id.uuid'] = params['monitor_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/monitors/{monitor.id.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateMonitorResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



"""NLP-specific data format checking class and artifacts."""
import gzip
import json
from pathlib import Path
from typing import IO, Any, Iterable, List, Optional

from schema import Schema, SchemaError
from tqdm import tqdm

from rime_sdk.data_format_check.data_format_checker import DataFormatChecker

# NLP Tasks
TEXT_CLASSIFICATION = "Text Classification"
NAMED_ENTITY_RECOGNITION = "Named Entity Recognition"
NLP_TASKS = {TEXT_CLASSIFICATION, NAMED_ENTITY_RECOGNITION}

# NLP JSON data schemas
# Text Classification
TC_SCHEMA_DEFAULT = Schema({"text": str}, ignore_extra_keys=True)
TC_SCHEMA_PREDS = Schema({"probabilities": [float]}, ignore_extra_keys=True)
TC_SCHEMA_MASTER = Schema(
    {"text": str, "label": int, "probabilities": [float]}, ignore_extra_keys=True
)
# Named Entity Recognition Schemas
NER_SCHEMA_DEFAULT = Schema({"text": str}, ignore_extra_keys=True)
# NER has dicts, which need their own schemas
NER_SCHEMA_MENTION = Schema(
    {"start_offset": int, "end_offset": int}, ignore_extra_keys=True
)
NER_SCHEMA_ENTITY = Schema(
    {"mentions": [NER_SCHEMA_MENTION], "type": str}, ignore_extra_keys=True
)
NER_SCHEMA_PREDS = Schema(
    {"predicted_entities": [NER_SCHEMA_ENTITY]}, ignore_extra_keys=True
)
NER_SCHEMA_MASTER = Schema(
    {
        "text": str,
        "entities": [NER_SCHEMA_ENTITY],
        "predicted_entities": [NER_SCHEMA_ENTITY],
    },
    ignore_extra_keys=True,
)

DEFAULT = "default"
PREDS = "preds"
MASTER = "master"
SCHEMA_BANK = {
    TEXT_CLASSIFICATION: {
        DEFAULT: TC_SCHEMA_DEFAULT,
        PREDS: TC_SCHEMA_PREDS,
        MASTER: TC_SCHEMA_MASTER,
    },
    NAMED_ENTITY_RECOGNITION: {
        DEFAULT: NER_SCHEMA_DEFAULT,
        PREDS: NER_SCHEMA_PREDS,
        MASTER: NER_SCHEMA_MASTER,
    },
}

# Validations can happen on these types of input
INPUT_PREDS_INCLUDED = "input_preds_included"
INPUT_PREDS_SEPARATE = "input_preds_separate"
PREDS = "preds"
INPUT_TYPES = set([INPUT_PREDS_INCLUDED, INPUT_PREDS_SEPARATE, PREDS])

ERROR_UNKNOWN_TASK = "Unrecognized NLP task: '{task}'. Task must be one of {tasks}"
ERROR_UNKNOWN_INPUT = (
    "Unrecognized input type: '{input_type}'. Input type must be one of {accepted}"
)


# NLP Data loading methods
def _load_data_from_file_object(file_object: IO, file_name: str) -> Iterable[dict]:
    path = Path(file_name)
    try:
        if path.suffix == ".json":
            yield from json.load(file_object)
        elif path.suffix == ".jsonl":
            for line in file_object:
                yield json.loads(line)
        else:
            raise ValueError(
                f"Only .json and .jsonl files supported. Got {path.suffix}"
            )
    finally:
        if not file_object.closed:
            file_object.close()


def _load_data_multi_ext(base_path: Path) -> Iterable[dict]:
    _gz_suffix = ".gz"
    if base_path.suffix == _gz_suffix:
        decompressed_name = str(base_path)[: -len(_gz_suffix)]
        file_object = gzip.open(str(base_path), "rt", encoding="utf-8")
        return _load_data_from_file_object(file_object, decompressed_name)
    else:
        file_object = base_path.open("r", encoding="utf-8")
        return _load_data_from_file_object(file_object, str(base_path))


def _load_data(data_path: Path) -> List[dict]:
    data = list(_load_data_multi_ext(data_path))
    return data


def check_json_nlp_data(
    file_path: Path,
    schema: Schema = None,
    task: str = "",
    input_type: Optional[str] = None,
) -> None:
    """Validate that all objects in the loaded JSON data match the given Schema.

    If no schema is provided, it will be inferred based on the task, first data point,
    and input_type.
    """

    if schema is None and (task is None or input_type is None):
        raise ValueError(
            "If schema is not provided, both task and input_type "
            "must be provided to enable schema inference."
        )
    elif schema is None and (task is not None and input_type is not None):
        if task not in NLP_TASKS:
            raise ValueError(ERROR_UNKNOWN_TASK.format(task=task, tasks=NLP_TASKS))
        if input_type not in INPUT_TYPES:
            raise ValueError(
                ERROR_UNKNOWN_INPUT.format(input_type=input_type, accepted=INPUT_TYPES)
            )

    list_data = _load_data(file_path)

    if list_data is None or len(list_data) == 0:
        raise ValueError(
            f"No objects parsed from '{file_path}'. Please verify "
            "presence and format of input data and retry."
        )

    schema = get_schema(schema, task, input_type, list_data)

    print(f"\nInspecting '{file_path}':")
    for i in tqdm(range(0, len(list_data))):
        try:
            # TODO(RAT-1940): add manual non-null/non-empty check
            schema.validate(list_data[i])
        except SchemaError as e:
            schema_str_trimmed = str(schema).replace("Schema(", "").replace(")", "")
            schema_msg = (
                f"\n\n---\n\nInputs for task '{task}' must adhere to the "
                f"following structure:\n\n{schema_str_trimmed}"
            )
            e.args = (
                f"File '{file_path}', Index {i}:\n\n",
                *e.args,
                schema_msg,
            )
            raise


def get_schema(
    schema: Optional[Schema],
    task: str,
    input_type: Optional[str],
    list_data: List[dict],
) -> Schema:
    """Infer the schema to use if schema is not provided."""
    if schema is not None:
        return schema

    # If schema is not provided, select or generate an appropriate one based
    # on first data point and task/presence of predictions
    if input_type == PREDS:
        return SCHEMA_BANK[task][PREDS]
    elif input_type == INPUT_PREDS_SEPARATE:
        return infer_schema_from_datapoint(
            task, list_data[0], set(SCHEMA_BANK[task][PREDS].schema.keys())
        )
    elif input_type == INPUT_PREDS_INCLUDED:
        return infer_schema_from_datapoint(task, list_data[0])
    else:
        raise ValueError(
            ERROR_UNKNOWN_INPUT.format(input_type=input_type, accepted=INPUT_TYPES)
        )


def infer_schema_from_datapoint(
    task: str, datapoint: dict, excluded_keys: Optional[Iterable] = None
) -> Schema:
    """Generate a custom schema using the given task and datapoint.

    Start with the default schema (contains only required keys), and add keys as they
    are observed in the datapoint.

    Use only those keys that are present in the "master schema", unless they've been
    explicitly excluded via excluded_keys.
    """
    generated_schema = Schema(
        schema=SCHEMA_BANK[task][DEFAULT].schema.copy(),
        ignore_extra_keys=SCHEMA_BANK[task][DEFAULT].ignore_extra_keys,
    )
    master_schema = SCHEMA_BANK[task][MASTER]

    datapoint_keys = list(datapoint.keys())
    master_schema_keys = set(master_schema.schema.keys())

    for key in datapoint_keys:
        if excluded_keys is not None:
            if key in master_schema_keys and key not in excluded_keys:
                generated_schema.schema.update({key: master_schema.schema.get(key)})
        elif key in master_schema_keys:
            generated_schema.schema.update({key: master_schema.schema.get(key)})

    return generated_schema


class NlpDataFormatChecker(DataFormatChecker):
    """Checker for NLP tasks."""

    accepted_file_types = [".json", ".jsonl", ".json.gz", ".jsonl.gz"]

    def check(
        self,
        ref_path: Path,
        eval_path: Path,
        task: str = "",
        preds_ref_path: Optional[Path] = None,
        preds_eval_path: Optional[Path] = None,
        **kwargs: Any,
    ) -> None:
        """Execute NLP data checks based on provided inputs.

        Uses rules defined in the global NLP data schemas.
        """

        self.check_file_format(ref_path)
        self.check_file_format(eval_path)

        # Assume predictions are included unless observed otherwise
        ref_input_type = INPUT_PREDS_INCLUDED
        if preds_ref_path is not None:
            self.check_file_format(preds_ref_path)
            check_json_nlp_data(preds_ref_path, None, task, PREDS)
            ref_input_type = INPUT_PREDS_SEPARATE

        eval_input_type = INPUT_PREDS_INCLUDED
        if preds_eval_path is not None:
            self.check_file_format(preds_eval_path)
            check_json_nlp_data(preds_eval_path, None, task, PREDS)
            eval_input_type = INPUT_PREDS_SEPARATE

        check_json_nlp_data(ref_path, None, task, ref_input_type)

        check_json_nlp_data(eval_path, None, task, eval_input_type)

        print("\n---\n")
        print(self.success_msg)



"""Setup file for package."""

from pathlib import Path

from setuptools import find_packages, setup

CUR_DIR = Path(__file__).parent

with open(CUR_DIR / "README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="rime_sdk",
    packages=find_packages(include=["rime_sdk*"]),
    description="Package to programmatically access a RIME deployment",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # TODO(VAL-2432): upgrade to semver 3 when it is released.
    setuptools_git_versioning={"enabled": True},
    setup_requires=["setuptools-git-versioning"],
    install_requires=[
        # Note: click is a dependency of `requests` but has to be pinned here
        # due to https://github.com/psf/black/issues/2964 .
        "click==8.0.1",
        "deprecated>=1.0.0,<2.0.0",
        "semver>=2.10.0,<3.0.0",
        "simplejson",
        "pandas>=1.1.0,<1.5.0",
        "requests>=2.0.0",
        "tqdm",
        "importlib_metadata",
        "protobuf",
        # below reqs are for data_format_check
        "schema",
        "numpy",
    ],
    python_requires=">=3.6",
    license="OSI Approved :: Apache Software License",
    entry_points={
        "console_scripts": [
            "rime-data-format-check=rime_sdk.data_format_check.cli:main",
        ]
    },
)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistrypredictionPrediction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset_id': 'str',
        'model_id': 'RimeUUID',
        'project_ids': 'list[RimeUUID]',
        'creator_id': 'RimeUUID',
        'creation_time': 'datetime',
        'user_metadata': 'RegistryMetadata',
        'integration_id': 'RimeUUID',
        'pred_info': 'RegistryPredInfo',
        'validity_status': 'RegistryValidityStatus',
        'marked_for_delete_at': 'datetime'
    }

    attribute_map = {
        'dataset_id': 'datasetId',
        'model_id': 'modelId',
        'project_ids': 'projectIds',
        'creator_id': 'creatorId',
        'creation_time': 'creationTime',
        'user_metadata': 'userMetadata',
        'integration_id': 'integrationId',
        'pred_info': 'predInfo',
        'validity_status': 'validityStatus',
        'marked_for_delete_at': 'markedForDeleteAt'
    }

    def __init__(self, dataset_id=None, model_id=None, project_ids=None, creator_id=None, creation_time=None, user_metadata=None, integration_id=None, pred_info=None, validity_status=None, marked_for_delete_at=None):  # noqa: E501
        """RegistrypredictionPrediction - a model defined in Swagger"""  # noqa: E501
        self._dataset_id = None
        self._model_id = None
        self._project_ids = None
        self._creator_id = None
        self._creation_time = None
        self._user_metadata = None
        self._integration_id = None
        self._pred_info = None
        self._validity_status = None
        self._marked_for_delete_at = None
        self.discriminator = None
        if dataset_id is not None:
            self.dataset_id = dataset_id
        if model_id is not None:
            self.model_id = model_id
        if project_ids is not None:
            self.project_ids = project_ids
        if creator_id is not None:
            self.creator_id = creator_id
        if creation_time is not None:
            self.creation_time = creation_time
        if user_metadata is not None:
            self.user_metadata = user_metadata
        if integration_id is not None:
            self.integration_id = integration_id
        if pred_info is not None:
            self.pred_info = pred_info
        if validity_status is not None:
            self.validity_status = validity_status
        if marked_for_delete_at is not None:
            self.marked_for_delete_at = marked_for_delete_at

    @property
    def dataset_id(self):
        """Gets the dataset_id of this RegistrypredictionPrediction.  # noqa: E501

        The dataset_id and model_id are used to uniquely identify a prediction. These must be provided by the user.  # noqa: E501

        :return: The dataset_id of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: str
        """
        return self._dataset_id

    @dataset_id.setter
    def dataset_id(self, dataset_id):
        """Sets the dataset_id of this RegistrypredictionPrediction.

        The dataset_id and model_id are used to uniquely identify a prediction. These must be provided by the user.  # noqa: E501

        :param dataset_id: The dataset_id of this RegistrypredictionPrediction.  # noqa: E501
        :type: str
        """

        self._dataset_id = dataset_id

    @property
    def model_id(self):
        """Gets the model_id of this RegistrypredictionPrediction.  # noqa: E501


        :return: The model_id of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this RegistrypredictionPrediction.


        :param model_id: The model_id of this RegistrypredictionPrediction.  # noqa: E501
        :type: RimeUUID
        """

        self._model_id = model_id

    @property
    def project_ids(self):
        """Gets the project_ids of this RegistrypredictionPrediction.  # noqa: E501

        For now, a pred will only have one project_id associated with it. We make this an array to allow pred's to be shared in the future.  # noqa: E501

        :return: The project_ids of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: list[RimeUUID]
        """
        return self._project_ids

    @project_ids.setter
    def project_ids(self, project_ids):
        """Sets the project_ids of this RegistrypredictionPrediction.

        For now, a pred will only have one project_id associated with it. We make this an array to allow pred's to be shared in the future.  # noqa: E501

        :param project_ids: The project_ids of this RegistrypredictionPrediction.  # noqa: E501
        :type: list[RimeUUID]
        """

        self._project_ids = project_ids

    @property
    def creator_id(self):
        """Gets the creator_id of this RegistrypredictionPrediction.  # noqa: E501


        :return: The creator_id of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this RegistrypredictionPrediction.


        :param creator_id: The creator_id of this RegistrypredictionPrediction.  # noqa: E501
        :type: RimeUUID
        """

        self._creator_id = creator_id

    @property
    def creation_time(self):
        """Gets the creation_time of this RegistrypredictionPrediction.  # noqa: E501


        :return: The creation_time of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this RegistrypredictionPrediction.


        :param creation_time: The creation_time of this RegistrypredictionPrediction.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def user_metadata(self):
        """Gets the user_metadata of this RegistrypredictionPrediction.  # noqa: E501


        :return: The user_metadata of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: RegistryMetadata
        """
        return self._user_metadata

    @user_metadata.setter
    def user_metadata(self, user_metadata):
        """Sets the user_metadata of this RegistrypredictionPrediction.


        :param user_metadata: The user_metadata of this RegistrypredictionPrediction.  # noqa: E501
        :type: RegistryMetadata
        """

        self._user_metadata = user_metadata

    @property
    def integration_id(self):
        """Gets the integration_id of this RegistrypredictionPrediction.  # noqa: E501


        :return: The integration_id of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this RegistrypredictionPrediction.


        :param integration_id: The integration_id of this RegistrypredictionPrediction.  # noqa: E501
        :type: RimeUUID
        """

        self._integration_id = integration_id

    @property
    def pred_info(self):
        """Gets the pred_info of this RegistrypredictionPrediction.  # noqa: E501


        :return: The pred_info of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: RegistryPredInfo
        """
        return self._pred_info

    @pred_info.setter
    def pred_info(self, pred_info):
        """Sets the pred_info of this RegistrypredictionPrediction.


        :param pred_info: The pred_info of this RegistrypredictionPrediction.  # noqa: E501
        :type: RegistryPredInfo
        """

        self._pred_info = pred_info

    @property
    def validity_status(self):
        """Gets the validity_status of this RegistrypredictionPrediction.  # noqa: E501


        :return: The validity_status of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: RegistryValidityStatus
        """
        return self._validity_status

    @validity_status.setter
    def validity_status(self, validity_status):
        """Sets the validity_status of this RegistrypredictionPrediction.


        :param validity_status: The validity_status of this RegistrypredictionPrediction.  # noqa: E501
        :type: RegistryValidityStatus
        """

        self._validity_status = validity_status

    @property
    def marked_for_delete_at(self):
        """Gets the marked_for_delete_at of this RegistrypredictionPrediction.  # noqa: E501

        If marked_for_delete_at is set, the document will be deleted after a TTL.  # noqa: E501

        :return: The marked_for_delete_at of this RegistrypredictionPrediction.  # noqa: E501
        :rtype: datetime
        """
        return self._marked_for_delete_at

    @marked_for_delete_at.setter
    def marked_for_delete_at(self, marked_for_delete_at):
        """Sets the marked_for_delete_at of this RegistrypredictionPrediction.

        If marked_for_delete_at is set, the document will be deleted after a TTL.  # noqa: E501

        :param marked_for_delete_at: The marked_for_delete_at of this RegistrypredictionPrediction.  # noqa: E501
        :type: datetime
        """

        self._marked_for_delete_at = marked_for_delete_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistrypredictionPrediction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistrypredictionPrediction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Library defining the interface to Data Collector."""

import base64
import itertools
import json
import logging
import sys
from datetime import datetime
from typing import Any, Dict, Iterable, Iterator, List, Optional, Union

from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.internal.swagger_utils import serialize_datetime_to_proto_timestamp
from rime_sdk.swagger import swagger_client
from rime_sdk.swagger.swagger_client import (
    ApiClient,
    PredictionsModelIdUuidBody,
    RimeStorePredictionsRequestPrediction,
)
from rime_sdk.swagger.swagger_client.models import (
    DatacollectorDatapointRow,
    DataDataStreamIdUuidBody,
    DatastreamProjectIdUuidBody,
    RimeUUID,
)

logger = logging.getLogger(__name__)

GRPC_MAX_BYTES_SIZE = 50_000


class DatapointIterator:
    """Iterator that transforms an iterator of inputs to datapoints."""

    def __init__(self, it: Iterator):
        """Initialize iterator."""
        self.it = it

    def __iter__(self) -> Iterator:
        """Return iterator."""
        return self

    def __next__(self) -> DatacollectorDatapointRow:
        """Take next datapoint and convert to proto datapoint."""
        input_data, label, timestamp, query_id = self.it.__next__()
        return convert_input_to_datapoint(input_data, timestamp, label, query_id)


def convert_input_to_datapoint(
    input_data: Dict,
    timestamp: Optional[datetime] = None,
    label: Optional[Union[Dict, int, float]] = None,
    query_id: Optional[Union[str, float, int]] = None,
) -> DatacollectorDatapointRow:
    """Convert input data to a datapoint."""
    datapoint = DatacollectorDatapointRow(
        input_data=json_serialize(input_data),
    )
    if label is not None:
        datapoint.label = json_serialize(label)
    if query_id is not None:
        datapoint.query_id = json_serialize(query_id)
    if timestamp is not None:
        datapoint.timestamp = serialize_datetime_to_proto_timestamp(timestamp)
    return datapoint


def json_serialize(serialize_object: Any) -> str:
    """Encode using UTF-8 or return as None."""
    return base64.b64encode(json.dumps(serialize_object).encode("utf-8")).decode(
        "utf-8"
    )


def validate_log_datapoints(
    inputs: List[Dict], lists_to_validate: List[Optional[List]], list_names: List[str]
) -> None:
    """Create string message with everything wrong with inputs to log datapoints.

    Returns None if no errors.
    """
    input_len = len(inputs)

    for index, elements in enumerate(lists_to_validate):
        if elements is not None and len(elements) != input_len:
            error_str = "Size Mismatch in {}: {} data points, {} {}".format(
                list_names[index], input_len, len(elements), list_names[index]
            )
            raise ValueError(error_str)


class DataCollector:
    """An interface to a Data Collector.

    A Data Collector allows users to log datapoints to be used in RIME
    at either a datapoint or batch level in a continuous stream.
    """

    def __init__(self, api_client: ApiClient, project_id: str) -> None:
        """Create a new Data Collector wrapper object.

        Arguments:
            api_client: ApiClient
                The client used to query the RIME cluster.
            project_id: str
                The Project ID associated with the Data Collector.
        """
        self._api_client = api_client
        self._project_id = project_id

    def register_data_stream(self) -> str:
        """Register a data stream with the Data Collector.

        A data stream is a location to which data can be uploaded.

        Returns:
            str:
                The ID of the registered data stream.
        """
        req = DatastreamProjectIdUuidBody(project_id=RimeUUID(self._project_id))
        with RESTErrorHandler():
            api = swagger_client.DataCollectorApi(self._api_client)
            res = api.data_collector_register_data_stream(
                body=req,
                project_id_uuid=self._project_id,
            )
        return res.data_stream_id.uuid

    def _upload_datapoints_with_buffer(
        self, data_stream_id: str, datapoints: Iterator[DatacollectorDatapointRow]
    ) -> List[str]:
        """Upload a list of Data Collector datapoints, buffering message size."""
        datapoint_list: List[DatacollectorDatapointRow] = []
        datapoint_ids: List[RimeUUID] = []

        bytes_counter = 0

        # Parse through datapoints, uploading the max amount that GRPC supports
        # each time
        with RESTErrorHandler():
            api = swagger_client.DataCollectorApi(self._api_client)
            for datapoint in datapoints:
                # Request will error if a single datapoint is too large
                # This is OK because if it does, it means that the user
                # is using the product in a way we don't currently want to support
                # 4MB GRPC Message limit is large enough
                if bytes_counter + sys.getsizeof(datapoint) > GRPC_MAX_BYTES_SIZE:
                    req = DataDataStreamIdUuidBody(
                        data_stream_id=RimeUUID(data_stream_id),
                        datapoints=datapoint_list,
                    )
                    with RESTErrorHandler():
                        resp = api.data_collector_store_datapoints(
                            data_stream_id_uuid=data_stream_id,
                            body=req,
                        )
                        datapoint_ids.extend(resp.datapoint_ids)
                    datapoint_list = []
                    bytes_counter = 0

                datapoint_list.append(datapoint)
                bytes_counter += sys.getsizeof(datapoint)
            # Upload remaining datapoints
            if len(datapoint_list) > 0:
                req = DataDataStreamIdUuidBody(
                    data_stream_id=RimeUUID(data_stream_id),
                    datapoints=datapoint_list,
                )
                with RESTErrorHandler():
                    resp = api.data_collector_store_datapoints(
                        data_stream_id_uuid=data_stream_id, body=req
                    )
                    datapoint_ids.extend(resp.datapoint_ids)
        return [datapoint_id.uuid for datapoint_id in datapoint_ids]

    def log_datapoints(
        self,
        data_stream_id: str,
        inputs: List[Dict],
        timestamps: Optional[List[datetime]] = None,
        labels: Optional[List[Union[Dict, int, float]]] = None,
        query_ids: Optional[List[Union[str, float, int]]] = None,
    ) -> List[str]:
        """Log datapoints in batches.

        Args:
            data_stream_id: str
                The ID of the data stream to log the datapoints.
            inputs: List[Dict]
                List of inputs to log to the Data Collector. Provide each input
                should as a dictionary. Feature names are dictionary keys, with
                their corresponding values.
            timestamps: Optional[List[datetime]]
                List of optional timestamps associated with each input. The default
                value is the timestamp when the log_datapoints method is called.
            labels: Optional[List[Union[Dict, int, float]]]
                List of optional labels associated with each input.
            query_ids: Optional[List[Union[str, float, int]]]
                List of optional query IDs associated with each input. This parameter
                is only relevant for ranking use cases.

        Returns:
            List[str]:
                List of the logged datapoint IDs.

        Raises:
            ValueError
                This error is generated when the length of the inputs, timestamps,
                labels, or query_ids lists are not equal.

        Example:
        This example registers a data stream and logs two datapoints to the
        registered data stream.

        .. code-block:: python

            data_stream_id = data_collector.register_data_stream()
            datapoint_ids = data_collector.log_datapoints(
            data_stream_id=data_stream_id,
                inputs=[
                    {"feature_1": 1, "feature_2": 2},
                    {"feature_1": 3, "feature_2": 4},
                ],
                timestamps=[
                    datetime(2020, 1, 1, 0, 0, 0),
                    datetime(2020, 1, 1, 0, 0, 1),
                ],
                labels=[{"label": "label_1"}, {"label": "label_2"}],
            )
        """
        # Validate Datapoint List
        validate_log_datapoints(
            inputs,
            [labels, timestamps, query_ids],
            ["labels", "timestamps", "query_ids"],
        )
        print("Logging datapoints...")

        # Easier for looping through options
        it_timestamps: Iterable[Any] = timestamps or itertools.repeat(None)
        it_labels: Iterable[Any] = labels or itertools.repeat(None)
        it_queries: Iterable[Any] = query_ids or itertools.repeat(None)

        data_vals = zip(
            inputs,
            it_labels,
            it_timestamps,
            it_queries,
        )
        datapoint_iterator = DatapointIterator(iter(data_vals))
        return self._upload_datapoints_with_buffer(data_stream_id, datapoint_iterator)

    def log_predictions(
        self, model_id: str, datapoint_ids: List[str], predictions: List[Dict]
    ) -> None:
        """Log predictions to the Data Collector.

        Args:
            model_id: str
                The ID of the model to log the predictions.
            datapoint_ids: List[str]
                List of datapoint IDs associated with each prediction.
            predictions: List[Dict]
                List of predictions to log to the Data Collector. Provide each
                prediction as a dictionary. Feature names are dictionary keys,
                with their corresponding values.

        Raises:
            ValueError
                This error is generated when the length of the datapoint_ids and
                predictions lists are not equal.

        Example:
        This example logs two predictions to the Data Collector.

        .. code-block:: python

            data_collector.log_predictions(
                model_id="model_id",
                datapoint_ids=["datapoint_id_1", "datapoint_id_2"],
                predictions=[
                    {"prediction": "prediction_1"}, {"prediction": "prediction_2"}
                ],
            )
        """
        if len(datapoint_ids) != len(predictions):
            raise ValueError(
                f"The length of the datapoint_ids and predictions lists must be equal."
                f"Received {len(datapoint_ids)} datapoint_ids and "
                f"{len(predictions)} predictions."
            )
        print("Logging predictions...")
        api = swagger_client.DataCollectorApi(self._api_client)
        preds_list: List[RimeStorePredictionsRequestPrediction] = []
        bytes_counter = 0
        for datapoint_id, prediction in zip(datapoint_ids, predictions):
            pred = RimeStorePredictionsRequestPrediction(
                datapoint_id=RimeUUID(datapoint_id),
                prediction=json_serialize(prediction),
            )
            preds_list.append(pred)
            bytes_counter += sys.getsizeof(pred)
            if bytes_counter + sys.getsizeof(pred) > GRPC_MAX_BYTES_SIZE:
                with RESTErrorHandler():
                    req = PredictionsModelIdUuidBody(
                        model_id=RimeUUID(model_id),
                        predictions=preds_list,
                    )
                    api.data_collector_store_predictions(
                        body=req,
                        model_id_uuid=model_id,
                    )

                preds_list = []
                bytes_counter = 0
        if len(preds_list) > 0:
            with RESTErrorHandler():
                req = PredictionsModelIdUuidBody(
                    model_id=RimeUUID(model_id),
                    predictions=preds_list,
                )
                api.data_collector_store_predictions(
                    body=req,
                    model_id_uuid=model_id,
                )



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeAPITokenInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'RimeUUID',
        'name': 'str',
        'suffix': 'str',
        'creation_time': 'datetime',
        'expiration_time': 'datetime',
        'workspace_id': 'RimeUUID',
        'user_id': 'str',
        'token_type': 'RimeTokenType'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'suffix': 'suffix',
        'creation_time': 'creationTime',
        'expiration_time': 'expirationTime',
        'workspace_id': 'workspaceId',
        'user_id': 'userId',
        'token_type': 'tokenType'
    }

    def __init__(self, id=None, name=None, suffix=None, creation_time=None, expiration_time=None, workspace_id=None, user_id=None, token_type=None):  # noqa: E501
        """RimeAPITokenInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._suffix = None
        self._creation_time = None
        self._expiration_time = None
        self._workspace_id = None
        self._user_id = None
        self._token_type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if suffix is not None:
            self.suffix = suffix
        if creation_time is not None:
            self.creation_time = creation_time
        if expiration_time is not None:
            self.expiration_time = expiration_time
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if user_id is not None:
            self.user_id = user_id
        if token_type is not None:
            self.token_type = token_type

    @property
    def id(self):
        """Gets the id of this RimeAPITokenInfo.  # noqa: E501


        :return: The id of this RimeAPITokenInfo.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RimeAPITokenInfo.


        :param id: The id of this RimeAPITokenInfo.  # noqa: E501
        :type: RimeUUID
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this RimeAPITokenInfo.  # noqa: E501

        The name of the API token.  # noqa: E501

        :return: The name of this RimeAPITokenInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RimeAPITokenInfo.

        The name of the API token.  # noqa: E501

        :param name: The name of this RimeAPITokenInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def suffix(self):
        """Gets the suffix of this RimeAPITokenInfo.  # noqa: E501

        The suffix of the API token, which is visible in the Robust Intelligence web application.  # noqa: E501

        :return: The suffix of this RimeAPITokenInfo.  # noqa: E501
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """Sets the suffix of this RimeAPITokenInfo.

        The suffix of the API token, which is visible in the Robust Intelligence web application.  # noqa: E501

        :param suffix: The suffix of this RimeAPITokenInfo.  # noqa: E501
        :type: str
        """

        self._suffix = suffix

    @property
    def creation_time(self):
        """Gets the creation_time of this RimeAPITokenInfo.  # noqa: E501


        :return: The creation_time of this RimeAPITokenInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this RimeAPITokenInfo.


        :param creation_time: The creation_time of this RimeAPITokenInfo.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def expiration_time(self):
        """Gets the expiration_time of this RimeAPITokenInfo.  # noqa: E501


        :return: The expiration_time of this RimeAPITokenInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """Sets the expiration_time of this RimeAPITokenInfo.


        :param expiration_time: The expiration_time of this RimeAPITokenInfo.  # noqa: E501
        :type: datetime
        """

        self._expiration_time = expiration_time

    @property
    def workspace_id(self):
        """Gets the workspace_id of this RimeAPITokenInfo.  # noqa: E501


        :return: The workspace_id of this RimeAPITokenInfo.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this RimeAPITokenInfo.


        :param workspace_id: The workspace_id of this RimeAPITokenInfo.  # noqa: E501
        :type: RimeUUID
        """

        self._workspace_id = workspace_id

    @property
    def user_id(self):
        """Gets the user_id of this RimeAPITokenInfo.  # noqa: E501

        The ID of the user who created the API token.  # noqa: E501

        :return: The user_id of this RimeAPITokenInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this RimeAPITokenInfo.

        The ID of the user who created the API token.  # noqa: E501

        :param user_id: The user_id of this RimeAPITokenInfo.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def token_type(self):
        """Gets the token_type of this RimeAPITokenInfo.  # noqa: E501


        :return: The token_type of this RimeAPITokenInfo.  # noqa: E501
        :rtype: RimeTokenType
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this RimeAPITokenInfo.


        :param token_type: The token_type of this RimeAPITokenInfo.  # noqa: E501
        :type: RimeTokenType
        """

        self._token_type = token_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeAPITokenInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeAPITokenInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeCategoryTestResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'severity': 'RimeSeverity',
        'suggestion': 'RimeSuggestion',
        'category_metrics': 'list[RimeCategoryMetric]',
        'test_batch_types': 'list[str]',
        'description': 'str',
        'severity_counts': 'RimeSeverityCounts',
        'failing_test_types': 'list[str]',
        'duration': 'float',
        'category_importance': 'float',
        'risk_category': 'RiskscoreRiskCategoryType',
        'test_category': 'TestrunTestCategoryType'
    }

    attribute_map = {
        'id': 'id',
        'severity': 'severity',
        'suggestion': 'suggestion',
        'category_metrics': 'categoryMetrics',
        'test_batch_types': 'testBatchTypes',
        'description': 'description',
        'severity_counts': 'severityCounts',
        'failing_test_types': 'failingTestTypes',
        'duration': 'duration',
        'category_importance': 'categoryImportance',
        'risk_category': 'riskCategory',
        'test_category': 'testCategory'
    }

    def __init__(self, id=None, severity=None, suggestion=None, category_metrics=None, test_batch_types=None, description=None, severity_counts=None, failing_test_types=None, duration=None, category_importance=None, risk_category=None, test_category=None):  # noqa: E501
        """RimeCategoryTestResult - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._severity = None
        self._suggestion = None
        self._category_metrics = None
        self._test_batch_types = None
        self._description = None
        self._severity_counts = None
        self._failing_test_types = None
        self._duration = None
        self._category_importance = None
        self._risk_category = None
        self._test_category = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if severity is not None:
            self.severity = severity
        if suggestion is not None:
            self.suggestion = suggestion
        if category_metrics is not None:
            self.category_metrics = category_metrics
        if test_batch_types is not None:
            self.test_batch_types = test_batch_types
        if description is not None:
            self.description = description
        if severity_counts is not None:
            self.severity_counts = severity_counts
        if failing_test_types is not None:
            self.failing_test_types = failing_test_types
        if duration is not None:
            self.duration = duration
        if category_importance is not None:
            self.category_importance = category_importance
        if risk_category is not None:
            self.risk_category = risk_category
        if test_category is not None:
            self.test_category = test_category

    @property
    def id(self):
        """Gets the id of this RimeCategoryTestResult.  # noqa: E501

        When combined with the test run ID, this uniquely identifies a category test result.  # noqa: E501

        :return: The id of this RimeCategoryTestResult.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RimeCategoryTestResult.

        When combined with the test run ID, this uniquely identifies a category test result.  # noqa: E501

        :param id: The id of this RimeCategoryTestResult.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def severity(self):
        """Gets the severity of this RimeCategoryTestResult.  # noqa: E501


        :return: The severity of this RimeCategoryTestResult.  # noqa: E501
        :rtype: RimeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this RimeCategoryTestResult.


        :param severity: The severity of this RimeCategoryTestResult.  # noqa: E501
        :type: RimeSeverity
        """

        self._severity = severity

    @property
    def suggestion(self):
        """Gets the suggestion of this RimeCategoryTestResult.  # noqa: E501


        :return: The suggestion of this RimeCategoryTestResult.  # noqa: E501
        :rtype: RimeSuggestion
        """
        return self._suggestion

    @suggestion.setter
    def suggestion(self, suggestion):
        """Sets the suggestion of this RimeCategoryTestResult.


        :param suggestion: The suggestion of this RimeCategoryTestResult.  # noqa: E501
        :type: RimeSuggestion
        """

        self._suggestion = suggestion

    @property
    def category_metrics(self):
        """Gets the category_metrics of this RimeCategoryTestResult.  # noqa: E501

        Category metrics are aggregated or important metrics for the category.  # noqa: E501

        :return: The category_metrics of this RimeCategoryTestResult.  # noqa: E501
        :rtype: list[RimeCategoryMetric]
        """
        return self._category_metrics

    @category_metrics.setter
    def category_metrics(self, category_metrics):
        """Sets the category_metrics of this RimeCategoryTestResult.

        Category metrics are aggregated or important metrics for the category.  # noqa: E501

        :param category_metrics: The category_metrics of this RimeCategoryTestResult.  # noqa: E501
        :type: list[RimeCategoryMetric]
        """

        self._category_metrics = category_metrics

    @property
    def test_batch_types(self):
        """Gets the test_batch_types of this RimeCategoryTestResult.  # noqa: E501

        List of the tests in the category.  # noqa: E501

        :return: The test_batch_types of this RimeCategoryTestResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._test_batch_types

    @test_batch_types.setter
    def test_batch_types(self, test_batch_types):
        """Sets the test_batch_types of this RimeCategoryTestResult.

        List of the tests in the category.  # noqa: E501

        :param test_batch_types: The test_batch_types of this RimeCategoryTestResult.  # noqa: E501
        :type: list[str]
        """

        self._test_batch_types = test_batch_types

    @property
    def description(self):
        """Gets the description of this RimeCategoryTestResult.  # noqa: E501

        Human-readable description of the category test result.  # noqa: E501

        :return: The description of this RimeCategoryTestResult.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RimeCategoryTestResult.

        Human-readable description of the category test result.  # noqa: E501

        :param description: The description of this RimeCategoryTestResult.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def severity_counts(self):
        """Gets the severity_counts of this RimeCategoryTestResult.  # noqa: E501


        :return: The severity_counts of this RimeCategoryTestResult.  # noqa: E501
        :rtype: RimeSeverityCounts
        """
        return self._severity_counts

    @severity_counts.setter
    def severity_counts(self, severity_counts):
        """Sets the severity_counts of this RimeCategoryTestResult.


        :param severity_counts: The severity_counts of this RimeCategoryTestResult.  # noqa: E501
        :type: RimeSeverityCounts
        """

        self._severity_counts = severity_counts

    @property
    def failing_test_types(self):
        """Gets the failing_test_types of this RimeCategoryTestResult.  # noqa: E501

        List of all the failing test types.  # noqa: E501

        :return: The failing_test_types of this RimeCategoryTestResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._failing_test_types

    @failing_test_types.setter
    def failing_test_types(self, failing_test_types):
        """Sets the failing_test_types of this RimeCategoryTestResult.

        List of all the failing test types.  # noqa: E501

        :param failing_test_types: The failing_test_types of this RimeCategoryTestResult.  # noqa: E501
        :type: list[str]
        """

        self._failing_test_types = failing_test_types

    @property
    def duration(self):
        """Gets the duration of this RimeCategoryTestResult.  # noqa: E501

        Duration is the total time in seconds for tests in that category.  # noqa: E501

        :return: The duration of this RimeCategoryTestResult.  # noqa: E501
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this RimeCategoryTestResult.

        Duration is the total time in seconds for tests in that category.  # noqa: E501

        :param duration: The duration of this RimeCategoryTestResult.  # noqa: E501
        :type: float
        """

        self._duration = duration

    @property
    def category_importance(self):
        """Gets the category_importance of this RimeCategoryTestResult.  # noqa: E501

        The relative importance of the category.  # noqa: E501

        :return: The category_importance of this RimeCategoryTestResult.  # noqa: E501
        :rtype: float
        """
        return self._category_importance

    @category_importance.setter
    def category_importance(self, category_importance):
        """Sets the category_importance of this RimeCategoryTestResult.

        The relative importance of the category.  # noqa: E501

        :param category_importance: The category_importance of this RimeCategoryTestResult.  # noqa: E501
        :type: float
        """

        self._category_importance = category_importance

    @property
    def risk_category(self):
        """Gets the risk_category of this RimeCategoryTestResult.  # noqa: E501


        :return: The risk_category of this RimeCategoryTestResult.  # noqa: E501
        :rtype: RiskscoreRiskCategoryType
        """
        return self._risk_category

    @risk_category.setter
    def risk_category(self, risk_category):
        """Sets the risk_category of this RimeCategoryTestResult.


        :param risk_category: The risk_category of this RimeCategoryTestResult.  # noqa: E501
        :type: RiskscoreRiskCategoryType
        """

        self._risk_category = risk_category

    @property
    def test_category(self):
        """Gets the test_category of this RimeCategoryTestResult.  # noqa: E501


        :return: The test_category of this RimeCategoryTestResult.  # noqa: E501
        :rtype: TestrunTestCategoryType
        """
        return self._test_category

    @test_category.setter
    def test_category(self, test_category):
        """Sets the test_category of this RimeCategoryTestResult.


        :param test_category: The test_category of this RimeCategoryTestResult.  # noqa: E501
        :type: TestrunTestCategoryType
        """

        self._test_category = test_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeCategoryTestResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeCategoryTestResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class JobReaderApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def job_reader_cancel_job(self, job_id, **kwargs):  # noqa: E501
        """CancelJob  # noqa: E501

        Cancels the job with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_cancel_job(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID of job to be cancelled. (required)
        :return: RimeCancelJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_reader_cancel_job_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.job_reader_cancel_job_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def job_reader_cancel_job_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """CancelJob  # noqa: E501

        Cancels the job with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_cancel_job_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID of job to be cancelled. (required)
        :return: RimeCancelJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_reader_cancel_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `job_reader_cancel_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/cancel/{jobId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCancelJobResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_reader_get_job(self, job_id, **kwargs):  # noqa: E501
        """GetJob  # noqa: E501

        Get a single job by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_get_job(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID (required)
        :param str view: Specifies how much information about the job to retrieve. The default behavior is the Basic view.   - JOB_VIEW_BASIC: Server responses only include basic information about the job, including type, status, and some job data.  - JOB_VIEW_FULL: Server responses include all available information about the job, including progress. Has greater performance requirements than the Basic view.
        :return: RimeGetJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_reader_get_job_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.job_reader_get_job_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def job_reader_get_job_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """GetJob  # noqa: E501

        Get a single job by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_get_job_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID (required)
        :param str view: Specifies how much information about the job to retrieve. The default behavior is the Basic view.   - JOB_VIEW_BASIC: Server responses only include basic information about the job, including type, status, and some job data.  - JOB_VIEW_FULL: Server responses include all available information about the job, including progress. Has greater performance requirements than the Basic view.
        :return: RimeGetJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id', 'view']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_reader_get_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `job_reader_get_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []
        if 'view' in params:
            query_params.append(('view', params['view']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{jobId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetJobResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_reader_get_project_id(self, job_id, **kwargs):  # noqa: E501
        """GetProjectID  # noqa: E501

        Returns the project ID of the project running the job with the specified job ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_get_project_id(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID belonging to the project. (required)
        :return: RimeGetProjectIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_reader_get_project_id_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.job_reader_get_project_id_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def job_reader_get_project_id_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """GetProjectID  # noqa: E501

        Returns the project ID of the project running the job with the specified job ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_get_project_id_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID belonging to the project. (required)
        :return: RimeGetProjectIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_reader_get_project_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `job_reader_get_project_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{jobId}/project-id', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetProjectIDResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_reader_get_test_run_id(self, job_id, **kwargs):  # noqa: E501
        """GetTestRunID  # noqa: E501

        Returns a test run ID based on a specified job ID. The job ID must be for a completed stress test job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_get_test_run_id(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID associated with the test run. (required)
        :return: RimeGetTestRunIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_reader_get_test_run_id_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.job_reader_get_test_run_id_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def job_reader_get_test_run_id_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """GetTestRunID  # noqa: E501

        Returns a test run ID based on a specified job ID. The job ID must be for a completed stress test job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_get_test_run_id_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: Unique job ID associated with the test run. (required)
        :return: RimeGetTestRunIDResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_reader_get_test_run_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `job_reader_get_test_run_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{jobId}/test-run-id', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetTestRunIDResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_reader_list_jobs_for_project(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListJobsForProject  # noqa: E501

        Returns a paginated list of jobs for a given project. The list can be filtered by job type and status.  #### Python pagination example:  ```python all_objects = [] # Required for authentication to all methods in the API. headers = {\"rime-api-key\": \"INSERT_API_TOKEN\"} # TODO page_token = \"\" # Initialize query parameters in a dictionary params = {\"INSERT_QUERY_PARAMETER\": \"INSERT_QUERY_VALUE\"} # TODO # Make requests until all results have been returned. while True:     # If the page_token from a previous response is not empty, we need to specify this     # token as a parameter to the next request in order to return the next page.     if page_token != \"\":         params = {\"page_token\": page_token}     res = requests.get(\"INSERT_METHOD_URI\", params=params, headers=headers) # TODO     if res.status_code != 200 :         raise ValueError(res)     res_json = res.json()     all_objects.extend(res_json['INSERT_OBJECT_KEY']) # TODO     page_token = res_json['nextPageToken']     # If all results have been returned, res_json['hasMore'] is false.     if not res_json[\"hasMore\"]:         break ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_list_jobs_for_project(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param list[str] first_page_query_selected_statuses: Specifies a set of statuses. The query only returns results with a status in the specified set. Specify no statuses to return all results.   - JOB_STATUS_PENDING: Resources have been created for the job but the job has not started yet.  - JOB_STATUS_FAILED: Blanket status for user or system-related job failure.  - JOB_STATUS_REQUESTED: The job descriptor exists but has no resources allocated. Jobs that remain in this status without moving to the PENDING status are at risk of entering the FAILED status.  - JOB_STATUS_CANCELLED: Job has been cancelled. Cancelled jobs cannot be recovered.
        :param list[str] first_page_query_selected_types: Specifies a set of types. The query only returns jobs with types in the specified set. Specify no types to return all results. Job types not tied to projects will not be returned.
        :param str page_token: The ListJobs query returns a pageToken after the first request.
        :param str page_size: The maximum number of Job objects to return in a single page.
        :param str view: Specifies how much information about each job to retrieve.   - JOB_VIEW_BASIC: Server responses only include basic information about the job, including type, status, and some job data.  - JOB_VIEW_FULL: Server responses include all available information about the job, including progress. Has greater performance requirements than the Basic view.
        :return: RimeListJobsForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_reader_list_jobs_for_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.job_reader_list_jobs_for_project_with_http_info(project_id_uuid, **kwargs)  # noqa: E501
            return data

    def job_reader_list_jobs_for_project_with_http_info(self, project_id_uuid, **kwargs):  # noqa: E501
        """ListJobsForProject  # noqa: E501

        Returns a paginated list of jobs for a given project. The list can be filtered by job type and status.  #### Python pagination example:  ```python all_objects = [] # Required for authentication to all methods in the API. headers = {\"rime-api-key\": \"INSERT_API_TOKEN\"} # TODO page_token = \"\" # Initialize query parameters in a dictionary params = {\"INSERT_QUERY_PARAMETER\": \"INSERT_QUERY_VALUE\"} # TODO # Make requests until all results have been returned. while True:     # If the page_token from a previous response is not empty, we need to specify this     # token as a parameter to the next request in order to return the next page.     if page_token != \"\":         params = {\"page_token\": page_token}     res = requests.get(\"INSERT_METHOD_URI\", params=params, headers=headers) # TODO     if res.status_code != 200 :         raise ValueError(res)     res_json = res.json()     all_objects.extend(res_json['INSERT_OBJECT_KEY']) # TODO     page_token = res_json['nextPageToken']     # If all results have been returned, res_json['hasMore'] is false.     if not res_json[\"hasMore\"]:         break ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reader_list_jobs_for_project_with_http_info(project_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id_uuid: Unique object ID. (required)
        :param list[str] first_page_query_selected_statuses: Specifies a set of statuses. The query only returns results with a status in the specified set. Specify no statuses to return all results.   - JOB_STATUS_PENDING: Resources have been created for the job but the job has not started yet.  - JOB_STATUS_FAILED: Blanket status for user or system-related job failure.  - JOB_STATUS_REQUESTED: The job descriptor exists but has no resources allocated. Jobs that remain in this status without moving to the PENDING status are at risk of entering the FAILED status.  - JOB_STATUS_CANCELLED: Job has been cancelled. Cancelled jobs cannot be recovered.
        :param list[str] first_page_query_selected_types: Specifies a set of types. The query only returns jobs with types in the specified set. Specify no types to return all results. Job types not tied to projects will not be returned.
        :param str page_token: The ListJobs query returns a pageToken after the first request.
        :param str page_size: The maximum number of Job objects to return in a single page.
        :param str view: Specifies how much information about each job to retrieve.   - JOB_VIEW_BASIC: Server responses only include basic information about the job, including type, status, and some job data.  - JOB_VIEW_FULL: Server responses include all available information about the job, including progress. Has greater performance requirements than the Basic view.
        :return: RimeListJobsForProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id_uuid', 'first_page_query_selected_statuses', 'first_page_query_selected_types', 'page_token', 'page_size', 'view']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_reader_list_jobs_for_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id_uuid' is set
        if ('project_id_uuid' not in params or
                params['project_id_uuid'] is None):
            raise ValueError("Missing the required parameter `project_id_uuid` when calling `job_reader_list_jobs_for_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id_uuid' in params:
            path_params['projectId.uuid'] = params['project_id_uuid']  # noqa: E501

        query_params = []
        if 'first_page_query_selected_statuses' in params:
            query_params.append(('firstPageQuery.selectedStatuses', params['first_page_query_selected_statuses']))  # noqa: E501
            collection_formats['firstPageQuery.selectedStatuses'] = 'multi'  # noqa: E501
        if 'first_page_query_selected_types' in params:
            query_params.append(('firstPageQuery.selectedTypes', params['first_page_query_selected_types']))  # noqa: E501
            collection_formats['firstPageQuery.selectedTypes'] = 'multi'  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'view' in params:
            query_params.append(('view', params['view']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/project/{projectId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListJobsForProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DataProfilingFeatureRelationshipInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'num_feats_to_profile': 'str',
        'compute_feature_relationships': 'bool',
        'compute_numeric_feature_relationships': 'bool',
        'ignore_nan_for_feature_relationships': 'bool'
    }

    attribute_map = {
        'num_feats_to_profile': 'numFeatsToProfile',
        'compute_feature_relationships': 'computeFeatureRelationships',
        'compute_numeric_feature_relationships': 'computeNumericFeatureRelationships',
        'ignore_nan_for_feature_relationships': 'ignoreNanForFeatureRelationships'
    }

    def __init__(self, num_feats_to_profile=None, compute_feature_relationships=None, compute_numeric_feature_relationships=None, ignore_nan_for_feature_relationships=None):  # noqa: E501
        """DataProfilingFeatureRelationshipInfo - a model defined in Swagger"""  # noqa: E501
        self._num_feats_to_profile = None
        self._compute_feature_relationships = None
        self._compute_numeric_feature_relationships = None
        self._ignore_nan_for_feature_relationships = None
        self.discriminator = None
        if num_feats_to_profile is not None:
            self.num_feats_to_profile = num_feats_to_profile
        if compute_feature_relationships is not None:
            self.compute_feature_relationships = compute_feature_relationships
        if compute_numeric_feature_relationships is not None:
            self.compute_numeric_feature_relationships = compute_numeric_feature_relationships
        if ignore_nan_for_feature_relationships is not None:
            self.ignore_nan_for_feature_relationships = ignore_nan_for_feature_relationships

    @property
    def num_feats_to_profile(self):
        """Gets the num_feats_to_profile of this DataProfilingFeatureRelationshipInfo.  # noqa: E501

        Number of features to profile for smart feature sampling.  # noqa: E501

        :return: The num_feats_to_profile of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :rtype: str
        """
        return self._num_feats_to_profile

    @num_feats_to_profile.setter
    def num_feats_to_profile(self, num_feats_to_profile):
        """Sets the num_feats_to_profile of this DataProfilingFeatureRelationshipInfo.

        Number of features to profile for smart feature sampling.  # noqa: E501

        :param num_feats_to_profile: The num_feats_to_profile of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :type: str
        """

        self._num_feats_to_profile = num_feats_to_profile

    @property
    def compute_feature_relationships(self):
        """Gets the compute_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501

        Specifies whether to compute feature relationships.  # noqa: E501

        :return: The compute_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :rtype: bool
        """
        return self._compute_feature_relationships

    @compute_feature_relationships.setter
    def compute_feature_relationships(self, compute_feature_relationships):
        """Sets the compute_feature_relationships of this DataProfilingFeatureRelationshipInfo.

        Specifies whether to compute feature relationships.  # noqa: E501

        :param compute_feature_relationships: The compute_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :type: bool
        """

        self._compute_feature_relationships = compute_feature_relationships

    @property
    def compute_numeric_feature_relationships(self):
        """Gets the compute_numeric_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501

        Specifies whether to compute feature relationships for numeric columns.  # noqa: E501

        :return: The compute_numeric_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :rtype: bool
        """
        return self._compute_numeric_feature_relationships

    @compute_numeric_feature_relationships.setter
    def compute_numeric_feature_relationships(self, compute_numeric_feature_relationships):
        """Sets the compute_numeric_feature_relationships of this DataProfilingFeatureRelationshipInfo.

        Specifies whether to compute feature relationships for numeric columns.  # noqa: E501

        :param compute_numeric_feature_relationships: The compute_numeric_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :type: bool
        """

        self._compute_numeric_feature_relationships = compute_numeric_feature_relationships

    @property
    def ignore_nan_for_feature_relationships(self):
        """Gets the ignore_nan_for_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501

        Specifies whether to ignore NaN values when computing feature relationships.  # noqa: E501

        :return: The ignore_nan_for_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_nan_for_feature_relationships

    @ignore_nan_for_feature_relationships.setter
    def ignore_nan_for_feature_relationships(self, ignore_nan_for_feature_relationships):
        """Sets the ignore_nan_for_feature_relationships of this DataProfilingFeatureRelationshipInfo.

        Specifies whether to ignore NaN values when computing feature relationships.  # noqa: E501

        :param ignore_nan_for_feature_relationships: The ignore_nan_for_feature_relationships of this DataProfilingFeatureRelationshipInfo.  # noqa: E501
        :type: bool
        """

        self._ignore_nan_for_feature_relationships = ignore_nan_for_feature_relationships

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataProfilingFeatureRelationshipInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataProfilingFeatureRelationshipInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectIdUuidModelBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_id': 'object',
        'name': 'str',
        'metadata': 'RegistryMetadata',
        'external_id': 'str',
        'model_info': 'RegistryModelInfo',
        'integration_id': 'RimeUUID',
        'skip_validation': 'bool',
        'agent_id': 'RimeUUID',
        'model_endpoint_integration_id': 'RimeUUID'
    }

    attribute_map = {
        'project_id': 'projectId',
        'name': 'name',
        'metadata': 'metadata',
        'external_id': 'externalId',
        'model_info': 'modelInfo',
        'integration_id': 'integrationId',
        'skip_validation': 'skipValidation',
        'agent_id': 'agentId',
        'model_endpoint_integration_id': 'modelEndpointIntegrationId'
    }

    def __init__(self, project_id=None, name=None, metadata=None, external_id=None, model_info=None, integration_id=None, skip_validation=None, agent_id=None, model_endpoint_integration_id=None):  # noqa: E501
        """ProjectIdUuidModelBody - a model defined in Swagger"""  # noqa: E501
        self._project_id = None
        self._name = None
        self._metadata = None
        self._external_id = None
        self._model_info = None
        self._integration_id = None
        self._skip_validation = None
        self._agent_id = None
        self._model_endpoint_integration_id = None
        self.discriminator = None
        if project_id is not None:
            self.project_id = project_id
        self.name = name
        if metadata is not None:
            self.metadata = metadata
        if external_id is not None:
            self.external_id = external_id
        if model_info is not None:
            self.model_info = model_info
        if integration_id is not None:
            self.integration_id = integration_id
        if skip_validation is not None:
            self.skip_validation = skip_validation
        if agent_id is not None:
            self.agent_id = agent_id
        if model_endpoint_integration_id is not None:
            self.model_endpoint_integration_id = model_endpoint_integration_id

    @property
    def project_id(self):
        """Gets the project_id of this ProjectIdUuidModelBody.  # noqa: E501

        Uniquely specifies a Project.  # noqa: E501

        :return: The project_id of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: object
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ProjectIdUuidModelBody.

        Uniquely specifies a Project.  # noqa: E501

        :param project_id: The project_id of this ProjectIdUuidModelBody.  # noqa: E501
        :type: object
        """

        self._project_id = project_id

    @property
    def name(self):
        """Gets the name of this ProjectIdUuidModelBody.  # noqa: E501

        Unique name of the Model.  # noqa: E501

        :return: The name of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectIdUuidModelBody.

        Unique name of the Model.  # noqa: E501

        :param name: The name of this ProjectIdUuidModelBody.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def metadata(self):
        """Gets the metadata of this ProjectIdUuidModelBody.  # noqa: E501


        :return: The metadata of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: RegistryMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ProjectIdUuidModelBody.


        :param metadata: The metadata of this ProjectIdUuidModelBody.  # noqa: E501
        :type: RegistryMetadata
        """

        self._metadata = metadata

    @property
    def external_id(self):
        """Gets the external_id of this ProjectIdUuidModelBody.  # noqa: E501

        External ID that can be used to identify the model.  # noqa: E501

        :return: The external_id of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this ProjectIdUuidModelBody.

        External ID that can be used to identify the model.  # noqa: E501

        :param external_id: The external_id of this ProjectIdUuidModelBody.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def model_info(self):
        """Gets the model_info of this ProjectIdUuidModelBody.  # noqa: E501


        :return: The model_info of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: RegistryModelInfo
        """
        return self._model_info

    @model_info.setter
    def model_info(self, model_info):
        """Sets the model_info of this ProjectIdUuidModelBody.


        :param model_info: The model_info of this ProjectIdUuidModelBody.  # noqa: E501
        :type: RegistryModelInfo
        """

        self._model_info = model_info

    @property
    def integration_id(self):
        """Gets the integration_id of this ProjectIdUuidModelBody.  # noqa: E501


        :return: The integration_id of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this ProjectIdUuidModelBody.


        :param integration_id: The integration_id of this ProjectIdUuidModelBody.  # noqa: E501
        :type: RimeUUID
        """

        self._integration_id = integration_id

    @property
    def skip_validation(self):
        """Gets the skip_validation of this ProjectIdUuidModelBody.  # noqa: E501

        Whether or not to validate the model you are registering. Validation ensures that the model is valid for Robust Intelligence's systems.  # noqa: E501

        :return: The skip_validation of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: bool
        """
        return self._skip_validation

    @skip_validation.setter
    def skip_validation(self, skip_validation):
        """Sets the skip_validation of this ProjectIdUuidModelBody.

        Whether or not to validate the model you are registering. Validation ensures that the model is valid for Robust Intelligence's systems.  # noqa: E501

        :param skip_validation: The skip_validation of this ProjectIdUuidModelBody.  # noqa: E501
        :type: bool
        """

        self._skip_validation = skip_validation

    @property
    def agent_id(self):
        """Gets the agent_id of this ProjectIdUuidModelBody.  # noqa: E501


        :return: The agent_id of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this ProjectIdUuidModelBody.


        :param agent_id: The agent_id of this ProjectIdUuidModelBody.  # noqa: E501
        :type: RimeUUID
        """

        self._agent_id = agent_id

    @property
    def model_endpoint_integration_id(self):
        """Gets the model_endpoint_integration_id of this ProjectIdUuidModelBody.  # noqa: E501


        :return: The model_endpoint_integration_id of this ProjectIdUuidModelBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_endpoint_integration_id

    @model_endpoint_integration_id.setter
    def model_endpoint_integration_id(self, model_endpoint_integration_id):
        """Sets the model_endpoint_integration_id of this ProjectIdUuidModelBody.


        :param model_endpoint_integration_id: The model_endpoint_integration_id of this ProjectIdUuidModelBody.  # noqa: E501
        :type: RimeUUID
        """

        self._model_endpoint_integration_id = model_endpoint_integration_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectIdUuidModelBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectIdUuidModelBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
